@@ -2340,3 +2340,460 @@ sub _escapeLiteral {
 
 
 1;
+
+__END__
+
+
+=pod
+
+=head1 NAME
+
+Uplug::Web - a web interface for Uplug
+
+=head1 IMPORTANT NOTE
+
+This part of Uplug is not maintained anymore and should not be considered to be stable and it is possible not enirely compatible with current versions of the software.
+
+=head1 UplugWeb v0.1 - Frequently Asked Questions
+
+This is a collection of frequently asked questions and their answers
+related to UplugWeb - the web interface to the Uplug tools.
+L<http://uplug.sourceforge.net>
+
+
+=head1 General
+
+
+=head2 What is UplugWeb?
+
+UplugWeb is the web interface of the Uplug corpus tools. Registered
+users can use Uplug on-line with small-size corpora. UplugWeb can be
+used to create and manage multi-lingual parallel corpora.
+
+
+=head2 Where is it?
+
+The original version of UplugWeb is installed at the Department of
+Linguistics and Philology at Uppsala University: 
+L<http://stp.ling.uu.se/cgi-bin/joerg/Uplug>
+Other installations may exist elsewhere. Let me
+(I<joerg@stp.ling.uu.se>) know if you see it anywhere!
+
+
+=head2 How do I use it?
+
+You may look at any public corpus in the collection (click on 
+I<Public corpora>). You have to register first before you can use any
+of the other features (click on I<Register now>). No personal data will be
+given further to third parties!
+
+
+=head2 Is it free?
+
+UplugWeb is free for non-commercial usage. It is provided "as-is". No
+warranties or guranaties are given. Read also the License Agreement
+when registering to UplugWeb. This service may dissapear without prior
+notice (hopefully not ;-))
+
+
+=head2 Can I download UplugWeb and install locally?
+
+Yes, you can! Go to L<http://uplug.sourceforge.net> and download the
+uplug-package. Follow the instructions in uplug/web/INSTALL or other
+information that is hopefully there soon.
+
+
+
+
+=head1 Registration and User Managment
+
+Links for registration and user management are collected in the
+second menu (I<User management>) in the left column.
+
+
+=head2 How do I register?
+
+Registration is easy! Click on I<Register now> and fill out the form. Fields
+marked with I<*> are required. Your e-mail adress will be used as your
+UplugWeb user name. Click on the I<send> button at the bottom if
+everything is ok and you agree to the license agreement. Hopefully,
+this finishes your registration and you may now login to your UplugWeb
+account by clicking on I<Login>.
+
+
+=head2 I forgot my password!
+
+Click on I<Lost Password> and type your e-mail adress that you used
+for registration. The password will be sent to you by e-mail when you
+click on the I<send> button.
+
+
+=head2 How do I view user information?
+
+Click on I<Uplug users> in the I<User management> menu. You may look
+at user details if you click on I<info>. All registered users can do
+that. The I<edit> function is not implemented yet.
+
+
+=head2 How can I change my password?
+
+Right now you can't! This will may be added in the next version.
+
+
+
+
+=head1 Corpus Management
+
+UplugWeb functions related to corpora and corpus management are
+collected in the I<Corpus management> menu in the left column.
+
+
+=head2 How do I create a corpus?
+
+A corpus in UplugWeb is a collection of one or more documents. Each
+document may have several translations. Click on I<Create new corpus>
+for creating a new corpus (surprise ;-). You have to specify a unique
+name for the corpus in your repository. The name has to be mo longer
+than 10 characters using ASCII letters [a-zA-Z] and '_'. You may, of
+course, have several corpora in your account! The corpus name will
+appear in the list of your corpora (I<My corpora>). Check the
+I<private> checkbox if you don't want your corpus to appear in the
+collection I<Public corpora>. Public corpora can not be changed by
+others but viewed and downloaded by everyone!
+
+Initially, the corpus is empty. You have to add documents using the
+I<add> link in the task list behind the corpus name.
+
+
+
+=head2 How do I add documents to my corpus?
+
+Use the I<add> link in the task-list behind the name of your corpus!
+You will see this task list for each corpus in I<My corpora>. If you
+click on I<add>, a new form will be opened. Corpus documents that you
+submit have to be in PLAIN TEXT FORMAT! Any annotation will be ignored
+and interpreted as common text. Choose the correct character encoding
+format in the I<Encoding> option menu! Defaullt encoding is Unicode
+UTF-8. All data submitted will be converted to UTF-8!
+
+A document has to have a unique name in the corpus. It has to be
+shorter than 16 characters using ASCII letters [a-zA-z], digits [0-9],
+dots '.' and underscores '_'. 
+
+There may be several translations of each document in the corpus. DO
+NOT CHOOSE DIFFERENT NAMES FOR EACH TRANSLATION OF THE SAME DOCUMENT!
+Translations may (should) have the same name as the original. Choose
+the language of each document to distinguish them!
+
+The local document itself is inserted in the I<Upload file>
+field. Add the document to the corpus by clicking on the I<submit>
+button.
+
+The upload size is restricted. The total amount of POST-data is
+limited. UplugWeb is intended for small-size corpora. However, you may
+add as many documents as you want to each corpus.
+
+
+=head2 How can I remove documents from a corpus?
+
+Removing documents can be done with the I<remove> function in the
+task-list that you can find for each corpus. Click on I<remove> and
+the corpus manager will be in "remove-mode" (you can see the mode by
+checking which of the tasks is not linked anymore in the
+task-list). Each document is represented by a link from the language
+identifier (e.g. 'en' for English) behind the document name. Click on
+the link that corresponds to the document you would like to remove. BE
+CAREFUL! CLICKING ON THE LINKS REMOVES IMMEDIATELY THE CORREPSONDING
+DOCUMENT!
+
+
+=head2 How can I remove the complete corpus?
+
+Click on I<remove> in the task-list behind the corpus name. A new for
+should appear in your browser. Check the checkbox that you are really
+sure to remove the entire corpus and click on I<submit>. The corpus
+will be deleted!
+
+
+=head2 Can I restore data that I removed by accident?
+
+Yes you can! Click on I<Restore documents> and click on the links in
+your collection of removed documents.
+
+
+=head2 Can I download documents from my repository?
+
+Not directly. But you can send documents to your e-mail adress. Select
+the I<send> mode in the corpus manager (in the task-list for one of
+your corpora) and click on the document you want to be sent to you.
+
+
+=head2 Can I look at my documents?
+
+Of course! The "view mode" is the default mode in the corpus
+manager. Otherwise you may always activate it by clicking on I<view>
+in the task-list for each corpus. If you click on document links the
+corresponding document will be shown in your browser. The display
+style is different depending on the type of document you're looking
+at. For some document types you will have the choice between different
+display styles (e.g. for word alignment files). Alignment files can
+even be modified/revised. Check further down!
+
+
+=head2 Can I show larger/smaller parts of the document at once?
+
+No! Not right now.
+
+
+=head2 Can I edit my documents?
+
+No! Not right now. This is potentially dangerous and therefore not
+supported (yet). For alignment files it is possible to modify the
+links using the edit-functions provided for these file types. See
+further down.
+
+
+
+=head2 Can I edit/modify sentence alignment files?
+
+Sentence alignment is done automatically and, therefore, often
+includes errors. If you open a sentence alignment file (I<sent>) from
+the view mode you will see linked up/down arrows around each sentence
+ID. Use these links to move the attached sentence up or down. You can
+do this using both display styles I<text> and I<xml> (default).
+
+Editing alignment files link by link is
+not very convenient if there are many follow-up errors. Check the file
+first before starting to rervise the alignment. Sometimes the
+alignment is totally out of control at some point and it is not worth
+doing the revision by hand in this way. Modify your
+original files instead and re-run the sentence aligner! (Check the
+section on sentence alignment in the description of the task manager)
+
+
+=head2 Can I edit word alignment files?
+
+Open the chosen word alignment file in view mode and click on I<edit>
+in the list of display styles. Word alignments will now be shown as
+link-matrix with checkboxes for each word pair. Change the links as
+you wish and click on the I<change> button if your satisfied. Go to
+the next sentence pair by clicking on I<next>.
+
+
+=head2 Can I word-align bitexts by hand?
+
+Yes you can!
+Open a sentence alignment file (the once called I<sent>) in view mode and 
+click on I<wordalign>. The system will create an empty word alignment
+file if there is no word alignment file for this language pair
+already. Otherwise it will open the existing one and you may edit it.
+
+
+
+=head2 What is the I<info> mode?
+
+There is some more information for each document (e.g. status
+infomation). Click on I<info> to activate the info mode and select the
+document by clicking on the corresponding link (if you are in the info
+mode).
+
+=head2 What is I<preprocess>?
+
+The I<preprocess> task automatically adds pre-processing processes to
+the queue for all documents from the chosen corpus that are still in
+plain text format. Documents will be pre-processed with
+language-specific pre-processing modules if available. Otherwise, it
+will add the I<basic> pre-processing modules that adds simple XML
+markup and runs the sentence splitter and the general
+tokenizer. Documents that have been finished will be sent to you. Look
+att the process queue in the I<task manager> to track queued processes.
+
+=head2 What is I<align>?
+
+The I<align> task automatically adds all sentence alignment processes
+to the process queue possible for the chosen corpus. Each document
+with one or more translations will be sentence aligned. All possible
+alignment pairs will be considered (only in one direction). NOTE:
+documents have to be tokenized before they can be aligned! There is a
+quick-task for doing this for all documents automatically:
+I<preprocess>. Otherwise, use the pre-processing functions described
+in the section about the Task Manager.
+
+=head2 What is I<index>?
+
+The I<index> function can be used to create CWB
+(L<http://www.ims.uni-stuttgart.de/projekte/CorpusWorkbench/index.html>)
+index files from the chosen corpus. All tokenized document will be
+indexed. Sentence alignments will be included as well. Indexed corpora
+can be searched using CQP and the I<CWB Query> function in corpus
+management menu. Note that the entire corpus will be in one index per
+language. Documents will not be seperated from each other!
+
+
+=head2 What is I<query>?
+
+By clicking on I<query> you will get to the CWB query form. From here
+you can search your indexed corpus data.
+
+
+=head2 How do I use the CWB in UplugWeb?
+
+First of all you have to index one or more corpora in youre
+repository (use I<index> in the corpus task-list). You can view all
+indeces and query each corpus by selecting I<CWB Query> from the
+corpus management menu. For each indexed corpus you will have a list
+of indexed sub-corpora linked to their language (using 2-letter
+language ID's). Select the sub-corpus you are interested in by
+clicking on the corresponding link. Now you should get the query form
+you may use for searching the data. Sentence alignment can also be
+searched (if available). Select the languages you want to include in
+the column to the right. More information about queries can be found
+elsewhere (....).
+
+
+
+
+
+=head1 Task Management
+
+
+The task manager is used to start Uplug processes and to manage
+running processes. New processes will be queued and executed when
+possible. There are several queues managed by UplugWeb:
+
+=over
+
+=item * todo: 
+
+the list of processes to be done
+
+=item * queued: 
+
+processes that have been taken by a server and wait for
+their execution
+
+=item * working: 
+
+processes in progress
+
+=item * done: 
+
+finished processes (only recent once)
+
+=item * failed: 
+
+processes that failed at some point (can be restarted)
+
+=back
+
+
+
+The I<Main> menu contains several tasks that can be run by the system:
+
+
+
+=over
+
+=item * pre-processing: 
+
+All kinds of pre-processing tasks such as basic XML
+markup, sentence splitting, tokenization, language-specific tools
+(tagging, chunking)
+
+=item * tagging: 
+
+POS tagger for several languages
+
+=item * parser/chunker: 
+
+Syntactic parsers/chunkers for several languages
+(currently only for English and Swedish)
+
+=item * sentence aligner: 
+
+Sentence alignment using Gale&Church's
+length-based alignment algorithm
+
+=item * word aligner: 
+
+Word alignment using the Clue Aligner and other tools
+(e.g. GIZA++)
+
+=back
+
+
+
+
+=head2 How do I tokenize a document?
+
+Go to I<pre-processing> and choose either the I<basic> pre-processing
+module or one of the language specific pre-processing modules if you
+have an appropriate document in your corpus. There will be a form for
+choosing documents from the corpus if you have appropriate once in
+your corpus. Click on the I<add jobb> button for sending the job to
+the process queue. (Note: Select the correct corpus up at the top of the
+page if you have several corpora in your repository!)
+
+The pre-processor will overwrite the original text-document and
+replace it with the tokenized XML version. It will also be sent by
+mail if the process is finished.
+
+You can also run the pre-processor on all documents in a corpus by
+clicking on the I<preprocess> taks in the corpus manager. Check the
+section on I<corpus management> above!
+
+
+=head2 How do I POS tag a document?
+
+Tokenize the document first. Then, choose the tagger from the
+I<tagger> menu and select the appropriate document from the
+corpus. You can switch between corpora at the top of the page. The
+old document will be overwritten and the result will be sent to you by
+e-mail.
+
+
+
+=head2 How do I sentence-align 2 documents?
+
+Go to the I<sentence aligner> and select the 2 documents you want to
+align. They have to be tokenized first! Add the job to the queue by
+clicking on I<add job>.
+
+The sentence
+aligner uses "hard boundaries" (paragraph breaks and page breaks) to
+synchronize the alignment process. They may cause problems (follow-up
+errors) if they are
+not detected correctly. A simple solution is to remove all double
+empty lines from the text files before submitting them to the UplugWeb
+repository.
+
+You can also run the sentence aligner for all possible document pairs
+ini a corpus by clicking on the I<align> task in the corpus
+manager. Check the section on I<corpus management> above.
+
+
+=head2 How do I word-align a bitext?
+
+Go to the I<word aligner> and select one of the three possible
+settings: I<basic>, I<advanced>, and I<GIZA++>. After that select one
+of the sentence aligned corpora in your repository (you have to
+sentence align first!). Click on I<add job> to add the alignment
+process to the queue.
+
+NOTE: Word alignment takes quite
+some time even for small corpora! Be patient! (This is a Uplug problem)
+
+More information about word alignment will be added later on.
+
+
+
+
+=head1 Local Installation
+
+You can install your own UplugWeb server! Download the uplug package
+from L<http://uplug.sourceforge.net> and follow the instructions in
+I<uplug/web/INSTALL> and other documentation if available ....
+
+
+
+=cut
